@@ -195,12 +195,14 @@ class AbstractWindow(QtWidgets.QMainWindow):
                 skip.add(group)
             self.__signalCache[group] += self.signalDisconnect(group, _pause=True)
 
-        yield
+        try:
+            yield
 
-        for group in set(groups) - skip:
-            if group in self.__signalCache:
-                for signal, func, type in self.__signalCache.pop(group):
-                    self.signalConnect(signal, func, type, group=group)
+        finally:
+            for group in set(groups) - skip:
+                if group in self.__signalCache:
+                    for signal, func, type in self.__signalCache.pop(group):
+                        self.signalConnect(signal, func, type, group=group)
 
     def signalPaused(self, group):
         """Determine if a signal group is paused."""
@@ -260,8 +262,14 @@ class AbstractWindow(QtWidgets.QMainWindow):
         pass
 
     def isDialog(self):
-        """Return if the window is a dialog."""
-        return isinstance(self.parent(), QtWidgets.QDialog)
+        """Return if the window is a dialog.
+        Note that this will not work in __init__().
+        If it is needed, attach it to the windowReady signal instead.
+        """
+        try:
+            return isinstance(self.parent(), QtWidgets.QDialog)
+        except RuntimeError:
+            return False
 
     def loadWindowPosition(self):
         """Load the previous position or centre the window.
@@ -364,16 +372,22 @@ class AbstractWindow(QtWidgets.QMainWindow):
         docstring of the module, and if that fails, it will grab
         the docstring of the current class.
         """
-        if text is None:
+        if text is None or isinstance(text, bool):
             docstring = inspect.getmodule(self).__doc__ or self.__class__.__doc__
             if docstring is None:
                 raise ValueError('unable to find docstring')
             text = inspect.cleandoc(docstring)
 
-        self.displayMessage(
-            title='About {}'.format(self.WindowName),
-            message=text,
-        )
+        try:
+            self.displayMessage(
+                title='About {}'.format(self.WindowName),
+                message=text,
+            )
+        except AttributeError:
+            self.displayMessage(
+                title='About',
+                message=text,
+            )
 
     @hybridmethod
     def show(cls, self, *args, **kwargs):
@@ -556,6 +570,8 @@ class AbstractWindow(QtWidgets.QMainWindow):
         """Close the window and mark it as closed."""
         self._windowClosed = True
         self.clearWindowInstance(self.WindowID)
+        if self.isDialog():
+            return self.parent().close()
         return super(AbstractWindow, self).closeEvent(event)
 
     def isClosed(self):
@@ -676,6 +692,51 @@ class AbstractWindow(QtWidgets.QMainWindow):
             return self.parent().resize(width, height)
         return super(AbstractWindow, self).resize(width, height)
 
+    def setMinimumWidth(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMinimumWidth(*args, **kwargs)
+        return super(AbstractWindow, self).setMinimumWidth(*args, **kwargs)
+
+    def setFixedWidth(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setFixedWidth(*args, **kwargs)
+        return super(AbstractWindow, self).setFixedWidth(*args, **kwargs)
+
+    def setMaximumWidth(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMaximumWidth(*args, **kwargs)
+        return super(AbstractWindow, self).setMaximumWidth(*args, **kwargs)
+
+    def setMinimumHeight(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMinimumHeight(*args, **kwargs)
+        return super(AbstractWindow, self).setMinimumHeight(*args, **kwargs)
+
+    def setFixedHeight(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setFixedHeight(*args, **kwargs)
+        return super(AbstractWindow, self).setFixedHeight(*args, **kwargs)
+
+    def setMaximumHeight(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMaximumHeight(*args, **kwargs)
+        return super(AbstractWindow, self).setMaximumHeight(*args, **kwargs)
+
+    def setMinimumSize(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMinimumSize(*args, **kwargs)
+        return super(AbstractWindow, self).setMinimumSize(*args, **kwargs)
+
+    def setFixedSize(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setFixedSize(*args, **kwargs)
+        return super(AbstractWindow, self).setFixedSize(*args, **kwargs)
+
+    def setMaximumSize(self, *args, **kwargs):
+        if self.isDialog():
+            return self.parent().setMaximumSize(*args, **kwargs)
+        return super(AbstractWindow, self).setMaximumSize(*args, **kwargs)
+
     def centreWindow(self, parentGeometry=None, childGeometry=None):
         """Centre the current window to its parent.
         In the case of overrides, the parent or child geometry may be provided.
