@@ -31,21 +31,19 @@ class RuntimeDraggingError(RuntimeError):
 
 
 def getMainWindow():
-    """Returns Nukes main window
+    """Returns the Nuke main window.
+    If nothing can be found, None will be returned.
     Source: https://github.com/fredrikaverpil/pyvfx-boilerplate/blob/master/boilerplate.py
     """
-
     for obj in QtWidgets.QApplication.topLevelWidgets():
         if obj.inherits('QMainWindow') and obj.metaObject().className() == 'Foundry::UI::DockMainWindow':
             return obj
-    raise RuntimeError('Could not find DockMainWindow instance')
 
 
 def deleteQtWindow(windowId):
     """Delete a window.
     Source: https://github.com/fredrikaverpil/pyvfx-boilerplate/blob/master/boilerplate.py
     """
-
     for obj in QtWidgets.QApplication.allWidgets():
         if obj.objectName() == windowId:
             obj.deleteLater()
@@ -55,7 +53,6 @@ def _removeMargins(widget):
     """Remove Nuke margins when docked UI
     Source: https://gist.github.com/maty974/4739917
     """
-
     for parent in (widget.parentWidget().parentWidget(), widget.parentWidget().parentWidget().parentWidget().parentWidget()):
         parent.layout().setContentsMargins(0, 0, 0, 0)
 
@@ -72,7 +69,6 @@ class Pane(object):
         """Automatically select a pane to attach to.
         If there are somehow no panels that exist then None will be returned.
         """
-
         for pane_func in cls.__PRIORITY:
             pane = pane_func.__get__(cls, None)()
             if pane is not None:
@@ -81,7 +77,6 @@ class Pane(object):
     @classmethod
     def find(cls, windowID):
         """Find which pane the WindowID is docked to."""
-
         current_pane = nuke.getPaneFor(windowID)
         if current_pane is None:
             return None
@@ -245,7 +240,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
         By default dockable must be True as Nuke provides no control
         over it when creating a panel.
         """
-
         if parent is None:
             parent = getMainWindow()
         super(NukeWindow, self).__init__(parent, **kwargs)
@@ -265,7 +259,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def closeEvent(self, event):
         """Special case for closing docked windows."""
-
         super(NukeWindow, self).clearWindowInstance(self.WindowID)
 
         if self.dockable():
@@ -288,25 +281,21 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def setDefaultSize(self, width, height):
         """Override of setDefaultSize to disable it if window is docked."""
-
         if not self.dockable():
             super(NukeWindow, self).setDefaultSize(width, height)
 
     def setDefaultWidth(self, width):
         """Override of setDefaultWidth to disable it if window is docked."""
-
         if not self.dockable():
             super(NukeWindow, self).setDefaultWidth(width)
 
     def setDefaultHeight(self, height):
         """Override of setDefaultHeight to disable it if window is docked."""
-
         if not self.dockable():
             super(NukeWindow, self).setDefaultHeight(height)
 
     def setDefaultPosition(self, x, y):
         """Override of setDefaultPosition to disable it if window is docked."""
-
         if not self.dockable():
             super(NukeWindow, self).setDefaultPosition(x, y)
 
@@ -315,13 +304,11 @@ class NukeWindow(NukeCommon, AbstractWindow):
         This will change the entire Nuke GUI so it's disabled by default.
         The force parameter can be set to override this behaviour.
         """
-
         if force:
             super(NukeWindow, self).setWindowPalette(program, version, style)
 
     def windowPalette(self):
         """Get the current window palette."""
-
         currentPalette = super(NukeWindow, self).windowPalette()
         if currentPalette is None:
             return 'Nuke.{}'.format(VERSION)
@@ -331,7 +318,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
         """Check if the window still exists.
         See if it is attached to any pane, or check the parents up to the QStackedWidget.
         """
-
         if self.dockable():
             if alternative:
                 return self.parent().parent().parent().parent().parent().parent().parent().parent() is not None
@@ -340,7 +326,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def floating(self, alternative=False):
         """Determine if the window is floating."""
-
         if self.dockable():
             if alternative:
                 try:
@@ -352,7 +337,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def siblings(self):
         """Count the number of siblings in the QStackedWidget."""
-
         if self.dockable():
             try:
                 return self.parent().parent().parent().parent().parent().parent().parent().parent().count()
@@ -364,18 +348,20 @@ class NukeWindow(NukeCommon, AbstractWindow):
         """Resize the window.
         Only resize after loading has finished if it's not docked to a panel.
         """
-
         if not self._windowLoaded:
             return self.windowReady.connect(partial(self.resize, *args, **kwargs))
 
-        if not self.dockable() or self.floating():
+        try:
+            floating = self.floating()
+        except RuntimeDraggingError:
+            floating = False
+        if not self.dockable() or floating:
             super(NukeWindow, self).resize(*args, **kwargs)
 
     def move(self, *args, **kwargs):
         """Move the window.
         Only move after loading has finished if it's not docked to a panel.
         """
-
         if not self._windowLoaded:
             return self.windowReady.connect(partial(self.move, *args, **kwargs))
 
@@ -384,12 +370,10 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def getAttachedPane(self):
         """Find the name of the pane the window is attached to."""
-
         return Pane.find(self.WindowID)
 
     def saveWindowPosition(self):
         """Save the window location."""
-
         if 'nuke' not in self.windowSettings:
             self.windowSettings['nuke'] = {}
         settings = self.windowSettings['nuke']
@@ -420,7 +404,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def loadWindowPosition(self):
         """Set the position of the window when loaded."""
-
         if self.dockable():
             return
         try:
@@ -438,7 +421,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def _parentOverride(self, usePane=False):
         """Get the widget that contains the correct size and position on screen."""
-
         try:
             if usePane:
                 pane = Pane.get(self.WindowID)
@@ -456,21 +438,18 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def width(self):
         """Override to get docked width."""
-
         if self.dockable():
             return self._parentOverride(usePane=True).width()
         return super(NukeWindow, self).width()
 
     def height(self):
         """Override to get docked height."""
-
         if self.dockable():
             return self._parentOverride(usePane=True).width()
         return super(NukeWindow, self).height()
 
     def _registerNukeCallbacks(self):
         """Register all callbacks."""
-
         numEvents = 0
         windowInstance = self.windowInstance()
         for group in windowInstance['callback'].keys():
@@ -486,7 +465,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def _unregisterNukeCallbacks(self, group=None):
         """Unregister all callbacks."""
-
         numEvents = 0
         windowInstance = self.windowInstance()
         for group in windowInstance['callback'].keys():
@@ -502,7 +480,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def removeCallback(self, func, group=None, nodeClass=None):
         """Remove an individual callback."""
-
         windowInstance = self.windowInstance()
         if group is None:
             groups = windowInstance['callback'].keys()
@@ -532,7 +509,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
     @hybridmethod
     def removeCallbacks(cls, self, group=None, windowInstance=None, windowID=None):
         """Remove a callback group or all callbacks."""
-
         # Handle classmethod
         if self is cls:
             if windowInstance is None and windowID is not None:
@@ -576,7 +552,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
         """Executed whenever a node is created by the user.
         Not called when loading existing scripts, pasting nodes, or undoing a delete.
         """
-
         self._addNukeCallbackGroup(group)
         self.windowInstance()['callback'][group]['onUserCreate'][func].add(nodeClass)
         if not self.__windowHidden:
@@ -589,7 +564,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
         """Executed when any node is created.
         Examples include loading a script (includes new file), pasting a node, selecting a menu item, or undoing a delete.
         """
-
         self._addNukeCallbackGroup(group)
         self.windowInstance()['callback'][group]['onCreate'][func].add(nodeClass)
         if not self.__windowHidden:
@@ -602,7 +576,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
         """Executed when a script is loaded.
         This will be called by onCreate (for root), and straight after onCreate.
         """
-
         self._addNukeCallbackGroup(group)
         self.windowInstance()['callback'][group]['onScriptLoad'][func].add(nodeClass)
         if not self.__windowHidden:
@@ -613,7 +586,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def addCallbackOnScriptSave(self, func, nodeClass=None, group=None):
         """Executed when the user tries to save a script."""
-
         self._addNukeCallbackGroup(group)
         self.windowInstance()['callback'][group]['onScriptSave'][func].add(nodeClass)
         if not self.__windowHidden:
@@ -624,7 +596,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def addCallbackOnScriptClose(self, func, nodeClass=None, group=None):
         """Executed when Nuke is exited or the script is closed."""
-
         self._addNukeCallbackGroup(group)
         self.windowInstance()['callback'][group]['onScriptClose'][func].add(nodeClass)
         if not self.__windowHidden:
@@ -663,7 +634,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
     @classmethod
     def clearWindowInstance(cls, windowID):
         """Close the last class instance."""
-
         try:
             previousInstance = super(NukeWindow, cls).clearWindowInstance(windowID)
         except TypeError:
@@ -681,7 +651,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def deferred(self, func, *args, **kwargs):
         """Execute a deferred command."""
-
         utils.executeDeferred(func, *args, **kwargs)
 
     def parent(self, *args, **kwargs):
@@ -696,14 +665,12 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
         This fix runs getMainWindow if loading isn't complete.
         """
-
         if not self.__useNukeTemporaryParent or self.dockable():
             return super(NukeWindow, self).parent(*args, **kwargs)
         return getMainWindow()
 
     def hideEvent(self, event):
         """Unregister callbacks and save window location."""
-
         if not event.spontaneous() and not self.isClosed():
             try:
                 self._unregisterNukeCallbacks()
@@ -714,7 +681,6 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def showEvent(self, event):
         """Register callbacks and update UI (if checkForChanges is defined)."""
-
         if not event.spontaneous():
             self._registerNukeCallbacks()
             self.__windowHidden = False
@@ -724,14 +690,12 @@ class NukeWindow(NukeCommon, AbstractWindow):
 
     def hide(self):
         """Hide the Nuke window."""
-
         if not self.dockable():
             return super(NukeWindow, self).hide()
 
     @hybridmethod
     def show(cls, self, *args, **kwargs):
         """Show the Nuke window."""
-
         # Window is already initialised
         if self is not cls:
             if self.dockable():
@@ -779,14 +743,17 @@ class NukeWindow(NukeCommon, AbstractWindow):
             except KeyError:
                 pane = Pane.auto()
 
-            if not hasattr(cls, 'WindowID'):
-                cls.WindowID = str(uuid.uuid4())
-                cls.saveWindowPosition = lambda *args, **kwargs: None
+            # Set WindowID if needed but disable saving
+            class WindowClass(cls):
+                if not hasattr(cls, 'WindowID'):
+                    WindowID = uuid.uuid4().hex
+                    def enableSaveWindowPosition(self, enable):
+                        return super(WindowClass, self).enableSaveWindowPosition(False)
 
             panel = panels.registerWidgetAsPanel(
                 widget=namespace,
-                name=getattr(cls, 'WindowName', 'New Window'),
-                id=cls.WindowID,
+                name=getattr(WindowClass, 'WindowName', 'New Window'),
+                id=WindowClass.WindowID,
                 create=True,
             )
             panel.addToPane(pane)
@@ -804,6 +771,13 @@ class NukeWindow(NukeCommon, AbstractWindow):
             win.setDockable(True, override=True)
         return win
 
+    @classmethod
+    def dialog(cls, parent=None, *args, **kwargs):
+        """Create the window as a dialog."""
+        if parent is None:
+            parent = getMainWindow()
+        return super(NukeWindow, cls).dialog(parent=parent, *args, **kwargs)
+
 
 class NukeBatchWindow(NukeCommon, StandaloneWindow):
     """Variant of the Standalone window for Nuke in batch mode.
@@ -813,7 +787,6 @@ class NukeBatchWindow(NukeCommon, StandaloneWindow):
     which does not allow windows), but that process is not able to
     correctly import the "_nuke" library.
     """
-
     def __init__(self, parent=None, **kwargs):
         super(NukeBatchWindow, self).__init__(parent, **kwargs)
         self.nuke = False
@@ -826,7 +799,6 @@ class NukeBatchWindow(NukeCommon, StandaloneWindow):
 
     def saveWindowPosition(self):
         """Save the window location."""
-
         if 'nuke' not in self.windowSettings:
             self.windowSettings['nuke'] = {}
         settings = self.windowSettings['nuke']
@@ -848,7 +820,6 @@ class NukeBatchWindow(NukeCommon, StandaloneWindow):
 
     def loadWindowPosition(self):
         """Set the position of the window when loaded."""
-
         key = self._getSettingsKey()
         try:
             width = self.windowSettings['nuke'][key]['width']
@@ -865,7 +836,6 @@ class NukeBatchWindow(NukeCommon, StandaloneWindow):
     @hybridmethod
     def show(cls, self, *args, **kwargs):
         """Load the window in Nuke batch mode."""
-
         # Window is already initialised
         if self is not cls:
             return super(NukeBatchWindow, self).show()
@@ -878,3 +848,10 @@ class NukeBatchWindow(NukeCommon, StandaloneWindow):
         kwargs['instance'] = False
         kwargs['exec_'] = True
         return super(NukeBatchWindow, cls).show(*args, **kwargs)
+
+    @classmethod
+    def dialog(cls, parent=None, *args, **kwargs):
+        """Create the window as a dialog."""
+        if parent is None:
+            parent = getMainWindow()
+        return super(NukeWindow, cls).dialog(parent=parent, *args, **kwargs)
